<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Copyright © 2011–%1 Markus Enzenberger</source>
        <translation>Авторское право © 2011–%1 Markus Enzenberger</translation>
    </message>
    <message>
        <source>Computer opponent for the board game Blokus</source>
        <translation>Оппонент компьютерной настольной игры Блокус</translation>
    </message>
    <message>
        <source>Pentobi %1</source>
        <extracomment>The argument is the application version.</extracomment>
        <translation>Pentobi %1</translation>
    </message>
</context>
<context>
    <name>AnalyzeDialog</name>
    <message>
        <source>Analysis speed:</source>
        <translation>Скорость анализа:</translation>
    </message>
    <message>
        <source>Fast</source>
        <translation>Быстро</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Нормально</translation>
    </message>
    <message>
        <source>Slow</source>
        <translation>Медленно</translation>
    </message>
</context>
<context>
    <name>AnalyzeGame</name>
    <message>
        <source>(No analysis)</source>
        <translation>(Без анализа)</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Coordinates</source>
        <translation>Координаты</translation>
    </message>
    <message>
        <source>Show variations</source>
        <translation>Показать вариации</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Светлая</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Темная</translation>
    </message>
    <message>
        <source>Colorblind light</source>
        <translation>Цветовая слепота светлая</translation>
    </message>
    <message>
        <source>Colorblind dark</source>
        <translation>Цветовая слепота темная</translation>
    </message>
    <message>
        <source>System</source>
        <extracomment>Name of theme using default system colors</extracomment>
        <translation>Системная</translation>
    </message>
    <message>
        <source>Move marking:</source>
        <translation>Отметка хода:</translation>
    </message>
    <message>
        <source>Last with dot</source>
        <translation>Последний с точкой</translation>
    </message>
    <message>
        <source>Last with number</source>
        <translation>Последний с номером</translation>
    </message>
    <message>
        <source>All with number</source>
        <translation>Все с номерами</translation>
    </message>
    <message>
        <source>None</source>
        <extracomment>Move marking/None</extracomment>
        <translation>Нет</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation>Анимации</translation>
    </message>
    <message>
        <source>Show comment:</source>
        <translation>Показать комментарий:</translation>
    </message>
    <message>
        <source>Always</source>
        <extracomment>Show-comment mode</extracomment>
        <translation>Всегда</translation>
    </message>
    <message>
        <source>As needed</source>
        <extracomment>Show-comment mode</extracomment>
        <translation>По необходимости</translation>
    </message>
    <message>
        <source>Never</source>
        <extracomment>Show-comment mode</extracomment>
        <translation>Никогда</translation>
    </message>
    <message>
        <source>Color theme:</source>
        <translation>Цветовая тема:</translation>
    </message>
    <message>
        <source>Move number</source>
        <extracomment>Check box in appearance dialog whether to show the move number in the status bar.</extracomment>
        <translation>Номер хода</translation>
    </message>
</context>
<context>
    <name>AsciiArtSaveDialog</name>
    <message>
        <source>Export ASCII Art</source>
        <translation>Экспортировать ASCII</translation>
    </message>
    <message>
        <source>Text files</source>
        <translation>Текстовый файл</translation>
    </message>
</context>
<context>
    <name>BoardContextMenu</name>
    <message>
        <source>Go to Move %1</source>
        <translation>Перейти к ходу %1</translation>
    </message>
    <message>
        <source>Move Annotation</source>
        <translation>Пояснение Хода</translation>
    </message>
    <message>
        <source>Move Annotation (%1)</source>
        <extracomment>The argument is the annotation symbol for the current move</extracomment>
        <translation>Пояснение Хода (%1)</translation>
    </message>
</context>
<context>
    <name>ButtonApply</name>
    <message>
        <source>Apply</source>
        <translation>Применить</translation>
    </message>
</context>
<context>
    <name>ButtonCancel</name>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>ButtonClose</name>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
<context>
    <name>ButtonOk</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>ComputerDialog</name>
    <message>
        <source>Computer plays:</source>
        <translation>Играть Компьютеру:</translation>
    </message>
    <message>
        <source>Level %1</source>
        <translation>Уровень %1</translation>
    </message>
</context>
<context>
    <name>DocbookReader</name>
    <message>
        <source>Previous</source>
        <extracomment>Go to previous page of user manual</extracomment>
        <translation>Пред.</translation>
    </message>
    <message>
        <source>Contents</source>
        <extracomment>Go to table of contents of user manual</extracomment>
        <translation>Начало</translation>
    </message>
    <message>
        <source>Next</source>
        <extracomment>Go to next page of user manual</extracomment>
        <translation>След.</translation>
    </message>
</context>
<context>
    <name>ExportImageDialog</name>
    <message>
        <source>Image width:</source>
        <translation>Ширина изображения:</translation>
    </message>
</context>
<context>
    <name>GameInfoDialog</name>
    <message>
        <source>Player Blue/Red:</source>
        <translation>Игрок Синий/Красный:</translation>
    </message>
    <message>
        <source>Player Purple:</source>
        <translation>Игрок Фиолетовый:</translation>
    </message>
    <message>
        <source>Player Green:</source>
        <translation>Игрок Зеленый:</translation>
    </message>
    <message>
        <source>Player Blue:</source>
        <translation>Игрок Синий:</translation>
    </message>
    <message>
        <source>Player Yellow/Green:</source>
        <translation>Игрок Желтый/Зеленый:</translation>
    </message>
    <message>
        <source>Player Orange:</source>
        <translation>Игрок Оранжевый:</translation>
    </message>
    <message>
        <source>Player Yellow:</source>
        <translation>Игрок Желтый:</translation>
    </message>
    <message>
        <source>Player Red:</source>
        <translation>Игрок Красный:</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Дата:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Время:</translation>
    </message>
    <message>
        <source>Event:</source>
        <translation>Событие:</translation>
    </message>
    <message>
        <source>Round:</source>
        <translation>Раунд:</translation>
    </message>
</context>
<context>
    <name>GameModel</name>
    <message>
        <source>Purple wins with 1 point.</source>
        <translation>Фиолетовый выигрывает с 1 очком.</translation>
    </message>
    <message>
        <source>Purple wins with %L1 points.</source>
        <translation>Фиолетовый выигрывает с %L1 очками.</translation>
    </message>
    <message>
        <source>Orange wins with 1 point.</source>
        <translation>Оранжевый выигрывает с 1 очком.</translation>
    </message>
    <message>
        <source>Orange wins with %L1 points.</source>
        <translation>Оранжевый выигрывает с %L1 очками.</translation>
    </message>
    <message>
        <source>Game ends in a tie.</source>
        <translation>Игра заканчивается ничьей.</translation>
    </message>
    <message>
        <source>Green wins with 1 point.</source>
        <translation>Зеленый выигрывает с 1 очком.</translation>
    </message>
    <message>
        <source>Green wins with %L1 points.</source>
        <translation>Зеленый выигрывает с %L1 очками.</translation>
    </message>
    <message>
        <source>Blue wins with 1 point.</source>
        <translation>Синий выигрывает с 1 очком.</translation>
    </message>
    <message>
        <source>Blue wins with %L1 points.</source>
        <translation>Синий выигрывает с %L1 очками.</translation>
    </message>
    <message>
        <source>Green wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>Зеленый побеждает (ничья).</translation>
    </message>
    <message>
        <source>Blue/Red wins with 1 point.</source>
        <translation>Синий/Красный выигрывают с 1 очком.</translation>
    </message>
    <message>
        <source>Blue/Red wins with %L1 points.</source>
        <translation>Синий/Красный выигрывают с %L1 очками.</translation>
    </message>
    <message>
        <source>Yellow/Green wins with 1 point.</source>
        <translation>Желтый/Зеленый выигрывают с 1 очком.</translation>
    </message>
    <message>
        <source>Yellow/Green wins with %L1 points.</source>
        <translation>Желтый/Зеленый выигрывают с %L1 очками.</translation>
    </message>
    <message>
        <source>Yellow/Green wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>Желтый/Зеленый побеждают (ничья).</translation>
    </message>
    <message>
        <source>Blue wins.</source>
        <translation>Синий побеждает.</translation>
    </message>
    <message>
        <source>Yellow wins.</source>
        <translation>Желтый побеждает.</translation>
    </message>
    <message>
        <source>Red wins.</source>
        <translation>Красный побеждает.</translation>
    </message>
    <message>
        <source>Red wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>Красный побеждает (ничья).</translation>
    </message>
    <message>
        <source>Yellow wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>Желтый побеждает (ничья).</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue and Yellow.</source>
        <translation>Игра заканчивается ничьей между Синим и Желтым.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue and Red.</source>
        <translation>Игра заканчивается ничьей между Синим и Красными.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Yellow and Red.</source>
        <translation>Игра заканчивается ничьей между Желтыми и Красными.</translation>
    </message>
    <message>
        <source>Game ends in a tie between all players.</source>
        <translation>Игра заканчивается ничьей между всеми игроками.</translation>
    </message>
    <message>
        <source>Green wins.</source>
        <translation>Зеленый побеждает.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Yellow and Red.</source>
        <translation>Игра заканчивается ничьей между Синим, Желтым и Красным.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Yellow and Green.</source>
        <translation>Игра заканчивается ничьей между Синим, Желтым и Зеленым.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Red and Green.</source>
        <translation>Игра заканчивается ничьей между Синим, Красным и Зеленым.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Yellow, Red and Green.</source>
        <translation>Игра заканчивается ничьей между Желтым, Красным и Зеленым.</translation>
    </message>
    <message>
        <source>Invalid Blokus SGF file. (%1)</source>
        <translation>Неверный файл Блокус SGF. (%1)</translation>
    </message>
    <message>
        <source>Clipboard is empty.</source>
        <translation>Буфер обмена пуст.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Без названия</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <extracomment>The argument is a number, which will be increased if a file with the same name already exists</extracomment>
        <translation>Без названия %1</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Новый Каталог</translation>
    </message>
    <message>
        <source>New Folder %1</source>
        <extracomment>The argument is a number, which will be increased if a folder with the same name already exists</extracomment>
        <translation>Новый Каталог %1</translation>
    </message>
    <message>
        <source>(Setup)</source>
        <translation>(Настройка)</translation>
    </message>
    <message>
        <source>(No moves)</source>
        <translation>(Нет ходов)</translation>
    </message>
    <message>
        <source>Move %1</source>
        <extracomment>The argument is the current move number.</extracomment>
        <translation>Ход %1</translation>
    </message>
    <message>
        <source>Unsupported character set</source>
        <translation>Неподдерживаемый набор символов</translation>
    </message>
</context>
<context>
    <name>GameVariantDialog</name>
    <message>
        <source>Classic</source>
        <translation>Классическая</translation>
    </message>
    <message>
        <source>Duo</source>
        <translation>Два игрока</translation>
    </message>
    <message>
        <source>Junior</source>
        <translation>Юниор</translation>
    </message>
    <message>
        <source>Trigon</source>
        <translation>Тригон</translation>
    </message>
    <message>
        <source>Nexos</source>
        <translation>Нексос</translation>
    </message>
    <message>
        <source>GembloQ</source>
        <translation>ГемблоQ</translation>
    </message>
    <message>
        <source>Callisto</source>
        <translation>Каллисто</translation>
    </message>
    <message>
        <source>Players:</source>
        <translation>Игроки:</translation>
    </message>
    <message>
        <source>Colors:</source>
        <translation>Цвета:</translation>
    </message>
</context>
<context>
    <name>GameViewDesktop</name>
    <message>
        <source>Computer is thinking…</source>
        <translation>Компьютер думает…</translation>
    </message>
    <message>
        <source>Running game analysis…</source>
        <translation>Начать анализ игры…</translation>
    </message>
    <message>
        <source>Computer is thinking… (up to %1 seconds remaining)</source>
        <translation>Компьютер думает… (осталось %1 секунд)</translation>
    </message>
    <message>
        <source>Computer is thinking… (up to %1 minutes remaining)</source>
        <translation>Компьютер думает… (осталось %1 минут)</translation>
    </message>
</context>
<context>
    <name>GotoMoveDialog</name>
    <message>
        <source>Move number:</source>
        <translation>Номер хода:</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <source>Pentobi Help</source>
        <translation>Помощь</translation>
    </message>
</context>
<context>
    <name>ImageSaveDialog</name>
    <message>
        <source>Save Image</source>
        <translation>Сохранить изображение</translation>
    </message>
    <message>
        <source>PNG image files</source>
        <translation>Файлы PNG</translation>
    </message>
    <message>
        <source>JPEG image files</source>
        <translation>Файлы JPEG</translation>
    </message>
</context>
<context>
    <name>InitialRatingDialog</name>
    <message>
        <source>Initialize your rating for this game variant.</source>
        <translation>Выберете свой рейтинг для этой игры.</translation>
    </message>
    <message>
        <source>Initial rating:</source>
        <translation>Начальный рейтинг:</translation>
    </message>
    <message>
        <source>Beginner</source>
        <translation>Начинающий</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>Эксперт</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Pentobi</source>
        <extracomment>Window title if no file is loaded.</extracomment>
        <translation>Pentobi</translation>
    </message>
    <message>
        <source>Game analysis is only possible in main variation.</source>
        <translation>Анализ игры возможен только в основной вариации.</translation>
    </message>
    <message>
        <source>Autosaved game was changed by another instance of Pentobi. Overwrite?</source>
        <translation>Автосохраненная игра была изменена другим экземпляром Pentobi. Переписать?</translation>
    </message>
    <message>
        <source>Your rating has increased from %1 to %2.</source>
        <translation>Ваш рейтинг вырос с %1 на %2.</translation>
    </message>
    <message>
        <source>Your rating has decreased from %1 to %2.</source>
        <translation>Ваш рейтинг снизился с %1 на %2.</translation>
    </message>
    <message>
        <source>Your rating stays at %1.</source>
        <translation>Ваш рейтинг остается на уровне %1.</translation>
    </message>
    <message>
        <source>Delete all rating information for the current game variant?</source>
        <translation>Удалить всю информацию рейтинга для текущей игры?</translation>
    </message>
    <message>
        <source>Delete all variations?</source>
        <translation>Удалить все вариации?</translation>
    </message>
    <message>
        <source>Save failed.</source>
        <translation>Сохранить не удалось.</translation>
    </message>
    <message>
        <source>End of tree was reached. Continue search from start of the tree?</source>
        <translation>Достигнут конец дерева. Продолжить поиск с начала дерева?</translation>
    </message>
    <message>
        <source>No comment found</source>
        <translation>Комментариев не найдено</translation>
    </message>
    <message>
        <source>%1 (modified)</source>
        <extracomment>Label for modified loaded game. The argument is the file name.</extracomment>
        <translation>%1 (измененная)</translation>
    </message>
    <message>
        <source>File has been modified by another application. Reload?</source>
        <translation>Файл был изменен другим приложением. Перезапустить?</translation>
    </message>
    <message>
        <source>Continue computer move?</source>
        <translation>Передать ход компьютеру?</translation>
    </message>
    <message>
        <source>Keep only position?</source>
        <translation>Сохранить только позицию?</translation>
    </message>
    <message>
        <source>Keep only subtree?</source>
        <translation>Сохранить только поддерево?</translation>
    </message>
    <message>
        <source>Open failed.</source>
        <translation>Открыть не удалось.</translation>
    </message>
    <message>
        <source>Start rated game with Purple against Pentobi level %1?</source>
        <translation>Начать игру Фиолетовым против Pentobi уровня %1?</translation>
    </message>
    <message>
        <source>Start rated game with Green against Pentobi level %1?</source>
        <translation>Начать игру Зеленым против Pentobi уровня %1?</translation>
    </message>
    <message>
        <source>Start rated game with Blue/Red against Pentobi level %1?</source>
        <translation>Начать игру Синим/Красным против Pentobi уровня %1?</translation>
    </message>
    <message>
        <source>Start rated game with Blue against Pentobi level %1?</source>
        <translation>Начать игру Синим против Pentobi уровня %1?</translation>
    </message>
    <message>
        <source>Start rated game with Orange against Pentobi level %1?</source>
        <translation>Начать игру Оранжевым против Pentobi уровня %1?</translation>
    </message>
    <message>
        <source>Start rated game with Yellow/Green against Pentobi level %1?</source>
        <translation>Начать игру Желтым/Зеленым против Pentobi уровня %1?</translation>
    </message>
    <message>
        <source>Start rated game with Yellow against Pentobi level %1?</source>
        <translation>Начать игру Желтым против Pentobi уровня %1?</translation>
    </message>
    <message>
        <source>Start rated game with Red against Pentobi level %1?</source>
        <translation>Начать игру Красным против Pentobi уровня %1?</translation>
    </message>
    <message>
        <source>You have not yet played rated games in this game variant.</source>
        <translation>Вы еще не играли в рейтинговые игры в этом варианте игры.</translation>
    </message>
    <message>
        <source>Truncate this subtree?</source>
        <translation>Защитить это поддерево?</translation>
    </message>
    <message>
        <source>Truncate children?</source>
        <translation>Защитить от детей?</translation>
    </message>
    <message>
        <source>Discard game?</source>
        <translation>Сбросить игру?</translation>
    </message>
    <message>
        <source>Pentobi %1 (level %2)</source>
        <extracomment>Player name for game info in rated game. First argument is version of Pentobi, second argument is level.</extracomment>
        <translation>Pentobi %1 (уровень %2)</translation>
    </message>
    <message>
        <source>Human</source>
        <extracomment>Player name for game info in rated game.</extracomment>
        <translation>Человек</translation>
    </message>
    <message>
        <source>Rated game</source>
        <translation>Рэйтинг</translation>
    </message>
    <message>
        <source>File has been modified by another application. Overwrite?</source>
        <translation>Файл был изменен другим приложением. Перезаписать?</translation>
    </message>
    <message>
        <source>%1 - Pentobi</source>
        <extracomment>Window title if file is loaded. The argument is the file name prepended with a star if the file has been modified.</extracomment>
        <translation>%1 - Pentobi</translation>
    </message>
    <message>
        <source>Not enough memory</source>
        <translation>Недостаточно памяти</translation>
    </message>
    <message>
        <source>Game analysis aborted</source>
        <translation>Анализ игры прерван</translation>
    </message>
    <message>
        <source>Computer move aborted</source>
        <translation>Ход Компьютера прерван</translation>
    </message>
    <message>
        <source>Rating information deleted</source>
        <translation>Удаление информации рейтинга</translation>
    </message>
    <message>
        <source>Variations deleted</source>
        <translation>Вариации удалены</translation>
    </message>
    <message>
        <source>File saved</source>
        <translation>Файл сохранен</translation>
    </message>
    <message>
        <source>Saving image failed or unsupported image format</source>
        <translation>Ошибка сохранения или неподдерживаемый формат изображения</translation>
    </message>
    <message>
        <source>Image saved</source>
        <translation>Изображение сохранено</translation>
    </message>
    <message>
        <source>Creating image failed</source>
        <translation>Не удалось создать изображение</translation>
    </message>
    <message>
        <source>Continuing rated game</source>
        <translation>Продолжение рейтинговой игры</translation>
    </message>
    <message>
        <source>Kept only position</source>
        <translation>Сохранять только позицию</translation>
    </message>
    <message>
        <source>Kept only subtree</source>
        <translation>Сохранять только поддерево</translation>
    </message>
    <message>
        <source>Variation is now %1</source>
        <translation>Текущая вариация %1</translation>
    </message>
    <message>
        <source>Children truncated</source>
        <translation>Защищено от детей</translation>
    </message>
    <message>
        <source>Setup</source>
        <extracomment>Small-screen label for setup mode (short for &quot;Setup Mode&quot;).</extracomment>
        <translation>Настроить</translation>
    </message>
    <message>
        <source>Setup Mode</source>
        <translation>Режим настройки</translation>
    </message>
    <message>
        <source>Rated</source>
        <extracomment>Label for ongoing rated game</extracomment>
        <translation>Рэйтинг</translation>
    </message>
    <message>
        <source>Rated %1</source>
        <extracomment>Small-screen label for finished rated game (short for &quot;Rated Game&quot;). The argument is the game number.</extracomment>
        <translation>Рэйтинг %1</translation>
    </message>
    <message>
        <source>Rated Game %1</source>
        <extracomment>Label for rated game. The argument is the game number.</extracomment>
        <translation>Рэйтинговая игра %1</translation>
    </message>
    <message>
        <source>Main Variation</source>
        <translation>Основная вариация</translation>
    </message>
    <message>
        <source>Beginning of Branch</source>
        <translation>Начало Ветки</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Комментарий</translation>
    </message>
    <message>
        <source>Settings</source>
        <extracomment>Menu item Computer/Settings</extracomment>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Find Move</source>
        <translation>Подсказать ход</translation>
    </message>
    <message>
        <source>Next Comment</source>
        <translation>Следующий комментарий</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>На весь экран</translation>
    </message>
    <message>
        <source>Game Info</source>
        <translation>Информация Об Игре</translation>
    </message>
    <message>
        <source>Move Number…</source>
        <translation>Номер хода...</translation>
    </message>
    <message>
        <source>Pentobi Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Новая</translation>
    </message>
    <message>
        <source>Rated Game</source>
        <translation>Рэйтинг игра</translation>
    </message>
    <message>
        <source>Open…</source>
        <translation>Открыть…</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Игра</translation>
    </message>
    <message>
        <source>Play Move</source>
        <extracomment>Play a single move</extracomment>
        <translation>Сыграть ход</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Save As…</source>
        <translation>Сохранить как…</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <source>Undo Move</source>
        <translation>Отменить Ход</translation>
    </message>
    <message>
        <source>Blue/Red</source>
        <translation>Синий/Красный</translation>
    </message>
    <message>
        <source>Purple</source>
        <translation>Фиолетовый</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>Зеленый</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>Синий</translation>
    </message>
    <message>
        <source>Yellow/Green</source>
        <translation>Желтый/Зеленый</translation>
    </message>
    <message>
        <source>Orange</source>
        <translation>Оранжевый</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation>Желтый</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>Красный</translation>
    </message>
    <message>
        <source>Pentobi failed to generate a move.</source>
        <translation>Pentobi не сумел сгенерировать ход.</translation>
    </message>
    <message>
        <source>Press back again to exit</source>
        <translation>Нажмите назад еще раз, чтобы выйти</translation>
    </message>
</context>
<context>
    <name>MenuComputer</name>
    <message>
        <source>Computer</source>
        <translation>Компьютер</translation>
    </message>
</context>
<context>
    <name>MenuEdit</name>
    <message>
        <source>Edit</source>
        <translation>Редактировать</translation>
    </message>
    <message>
        <source>Make Main Variation</source>
        <translation>Сделать основной вариацией</translation>
    </message>
    <message>
        <source>Variation Up</source>
        <extracomment>Short for Move Variation Up</extracomment>
        <translation>Вариация выше</translation>
    </message>
    <message>
        <source>Variation Down</source>
        <extracomment>Short for Move Variation Down</extracomment>
        <translation>Вариант ниже</translation>
    </message>
    <message>
        <source>Delete Variations</source>
        <translation>Удалить вариации</translation>
    </message>
    <message>
        <source>Truncate</source>
        <translation>Защита</translation>
    </message>
    <message>
        <source>Truncate Children</source>
        <translation>Защита от детей</translation>
    </message>
    <message>
        <source>Keep Position</source>
        <translation>Сохранить Позицию</translation>
    </message>
    <message>
        <source>Keep Subtree</source>
        <translation>Сохранить Поддерево</translation>
    </message>
    <message>
        <source>Setup Mode</source>
        <translation>Режим Настройки</translation>
    </message>
    <message>
        <source>Next Color</source>
        <translation>Следующий Цвет</translation>
    </message>
    <message>
        <source>Annotation…</source>
        <translation>Пояснение…</translation>
    </message>
    <message>
        <source>Made main variation</source>
        <translation>Основные изменения</translation>
    </message>
</context>
<context>
    <name>MenuExport</name>
    <message>
        <source>Export</source>
        <translation>Экспорт</translation>
    </message>
    <message>
        <source>Image…</source>
        <translation>Изображение…</translation>
    </message>
    <message>
        <source>ASCII Art…</source>
        <translation>ASCII…</translation>
    </message>
</context>
<context>
    <name>MenuGame</name>
    <message>
        <source>Game</source>
        <translation>Игра</translation>
    </message>
    <message>
        <source>Game Variant…</source>
        <translation>Вариант игры...</translation>
    </message>
    <message>
        <source>Open Clipboard</source>
        <translation>Открыть Буфер обмена</translation>
    </message>
</context>
<context>
    <name>MenuGo</name>
    <message>
        <source>Go</source>
        <translation>Ход</translation>
    </message>
</context>
<context>
    <name>MenuHelp</name>
    <message>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <source>About Pentobi</source>
        <translation>О Pentobi</translation>
    </message>
    <message>
        <source>Report Bug</source>
        <translation>Сообщить об ошибке</translation>
    </message>
</context>
<context>
    <name>MenuRecentFiles</name>
    <message>
        <source>Open Recent</source>
        <translation>Открыть Недавние</translation>
    </message>
    <message>
        <source>Clear List</source>
        <extracomment>Menu item for clearing the recent files list</extracomment>
        <translation>Очистить Список</translation>
    </message>
</context>
<context>
    <name>MenuTools</name>
    <message>
        <source>Tools</source>
        <translation>Инструменты</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Рейтинг</translation>
    </message>
    <message>
        <source>Clear Rating</source>
        <translation>Очистить Рейтинг</translation>
    </message>
    <message>
        <source>Clear Analysis</source>
        <translation>Очистить Анализ</translation>
    </message>
    <message>
        <source>Analyze Game…</source>
        <translation>Анализировать игру…</translation>
    </message>
</context>
<context>
    <name>MenuView</name>
    <message>
        <source>View</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Внешний вид</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Панель инструментов</translation>
    </message>
</context>
<context>
    <name>MoveAnnotationDialog</name>
    <message>
        <source>Move %1</source>
        <translation>Ход %1</translation>
    </message>
    <message>
        <source>Very good</source>
        <translation>Очень хорошо</translation>
    </message>
    <message>
        <source>Good</source>
        <translation>Хорошо</translation>
    </message>
    <message>
        <source>Interesting</source>
        <translation>Интересно</translation>
    </message>
    <message>
        <source>Doubtful</source>
        <translation>Сомнительно</translation>
    </message>
    <message>
        <source>Bad</source>
        <translation>Плохо</translation>
    </message>
    <message>
        <source>Very Bad</source>
        <translation>Очень плохо</translation>
    </message>
    <message>
        <source>No annotation</source>
        <translation>Нет аннотации</translation>
    </message>
</context>
<context>
    <name>NewFolderDialog</name>
    <message>
        <source>Folder name:</source>
        <translation>Имя каталога:</translation>
    </message>
</context>
<context>
    <name>OpenDialog</name>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>Blokus games</source>
        <translation>Игры Блокус</translation>
    </message>
</context>
<context>
    <name>PentobiFileDialog</name>
    <message>
        <source>Overwrite file?</source>
        <translation>Перезаписать файл?</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Все файлы</translation>
    </message>
</context>
<context>
    <name>PentobiMenuItem</name>
    <message>
        <source>Ctrl</source>
        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Shift</source>
        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
        <translation>Shift</translation>
    </message>
</context>
<context>
    <name>PentobiToolBar</name>
    <message>
        <source>Start a new game</source>
        <translation>Начать новую игру</translation>
    </message>
    <message>
        <source>Start a rated game</source>
        <translation>Начать рейтинговую игру</translation>
    </message>
    <message>
        <source>Set the colors played by the computer</source>
        <translation>Установите цвета игроков компьютера</translation>
    </message>
    <message>
        <source>Make the computer continue to play the current color</source>
        <translation>Сделать так, чтобы компьютер продолжал играть в текущем цвете</translation>
    </message>
    <message>
        <source>Make the computer play the current color</source>
        <translation>Сделать так, чтобы компьютер играл в текущем цвете</translation>
    </message>
    <message>
        <source>Go to beginning of game</source>
        <translation>К началу игры</translation>
    </message>
    <message>
        <source>Go ten moves backward</source>
        <translation>На десять ходов назад</translation>
    </message>
    <message>
        <source>Go one move backward</source>
        <translation>На один шаг назад</translation>
    </message>
    <message>
        <source>Go one move forward</source>
        <translation>Вперед на один ход</translation>
    </message>
    <message>
        <source>Go ten moves forward</source>
        <translation>Вперед на десять ходов</translation>
    </message>
    <message>
        <source>Go to end of moves</source>
        <translation>К концу ходов</translation>
    </message>
    <message>
        <source>Go to previous variation</source>
        <translation>К предыдущему варианту</translation>
    </message>
    <message>
        <source>Go to next variation</source>
        <translation>К следующему варианту</translation>
    </message>
    <message>
        <source>Abort game analysis</source>
        <translation>Прервать анализ игры</translation>
    </message>
    <message>
        <source>Abort computer move</source>
        <translation>Прервать перемещение компьютера</translation>
    </message>
    <message>
        <source>Undo move</source>
        <extracomment>Tooltip for Undo button</extracomment>
        <translation>Отменить Ход</translation>
    </message>
    <message>
        <source>Open menu</source>
        <translation>Открыть меню</translation>
    </message>
</context>
<context>
    <name>RatingDialog</name>
    <message>
        <source>Your rating:</source>
        <translation>Ваш рейтинг:</translation>
    </message>
    <message>
        <source>Game variant:</source>
        <translation>Вариант игры:</translation>
    </message>
    <message>
        <source>Classic (2)</source>
        <extracomment>Short for Classic (2 players)</extracomment>
        <translation>Классическая (2)</translation>
    </message>
    <message>
        <source>Classic (3)</source>
        <extracomment>Short for Classic (3 players)</extracomment>
        <translation>Классическая (3)</translation>
    </message>
    <message>
        <source>Classic (4)</source>
        <extracomment>Short for Classic (4 players)</extracomment>
        <translation>Классическая (4)</translation>
    </message>
    <message>
        <source>Duo</source>
        <translation>Два игрока</translation>
    </message>
    <message>
        <source>Junior</source>
        <translation>Юниор</translation>
    </message>
    <message>
        <source>Trigon (2)</source>
        <extracomment>Short for Trigon (2 players)</extracomment>
        <translation>Тригон (2)</translation>
    </message>
    <message>
        <source>Trigon (3)</source>
        <extracomment>Short for Trigon (3 players)</extracomment>
        <translation>Тригон (3)</translation>
    </message>
    <message>
        <source>Trigon (4)</source>
        <extracomment>Short for Trigon (4 players)</extracomment>
        <translation>Тригон (4)</translation>
    </message>
    <message>
        <source>Nexos (2)</source>
        <extracomment>Short for Nexos (2 players)</extracomment>
        <translation>Нексос (2)</translation>
    </message>
    <message>
        <source>Nexos (4)</source>
        <extracomment>Short for Nexos (4 players)</extracomment>
        <translation>Нексос (4)</translation>
    </message>
    <message>
        <source>Callisto (2)</source>
        <extracomment>Short for Callisto (2 players, 2 colors)</extracomment>
        <translation>Каллисто (2)</translation>
    </message>
    <message>
        <source>Callisto (2/4)</source>
        <extracomment>Short for Callisto (2 players, 4 colors)</extracomment>
        <translation>Каллисто (2/4)</translation>
    </message>
    <message>
        <source>Callisto (3)</source>
        <extracomment>Short for Callisto (3 players)</extracomment>
        <translation>Каллисто (3)</translation>
    </message>
    <message>
        <source>Callisto (4)</source>
        <extracomment>Short for Callisto (4 players)</extracomment>
        <translation>Каллисто (4)</translation>
    </message>
    <message>
        <source>GembloQ (4)</source>
        <extracomment>Short for GembloQ (4 players)</extracomment>
        <translation>ГемблоQ (4)</translation>
    </message>
    <message>
        <source>GembloQ (2)</source>
        <extracomment>Short for GembloQ (2 players, 2 colors)</extracomment>
        <translation>ГемблоQ (2)</translation>
    </message>
    <message>
        <source>GembloQ (2/4)</source>
        <extracomment>Short for GembloQ (2 players, 4 colors)</extracomment>
        <translation>ГемблоQ (2/4)</translation>
    </message>
    <message>
        <source>GembloQ (3)</source>
        <extracomment>Short for GembloQ (3 players)</extracomment>
        <translation>ГемблоQ (3)</translation>
    </message>
    <message>
        <source>Rated games:</source>
        <translation>Рэйтинг:</translation>
    </message>
    <message>
        <source>Best previous rating:</source>
        <translation>Лучший предыдущий рейтинг:</translation>
    </message>
    <message>
        <source>Recent development:</source>
        <translation>Последняя разработка:</translation>
    </message>
    <message>
        <source>Open Game %1</source>
        <translation>Открыть Игру %1</translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Blokus games</source>
        <translation>Игры Блокус</translation>
    </message>
</context>
<context>
    <name>TableModel</name>
    <message>
        <source>Game</source>
        <extracomment>Table header for game number in rating dialog</extracomment>
        <translation>Игра</translation>
    </message>
    <message>
        <source>Result</source>
        <extracomment>Table header for game result in rating dialog</extracomment>
        <translation>Результат</translation>
    </message>
    <message>
        <source>Level</source>
        <extracomment>Table header for level in rating dialog</extracomment>
        <translation>Уровень</translation>
    </message>
    <message>
        <source>Your Color</source>
        <extracomment>Table header for player color(s) in rating dialog</extracomment>
        <translation>Ваш Цвет</translation>
    </message>
    <message>
        <source>Date</source>
        <extracomment>Table header for game date in rating dialog</extracomment>
        <translation>Дата:</translation>
    </message>
    <message>
        <source>Win</source>
        <extracomment>Result of rated game is a win</extracomment>
        <translation>Победа</translation>
    </message>
    <message>
        <source>Loss</source>
        <extracomment>Result of rated game is a loss</extracomment>
        <translation>Проигрыш</translation>
    </message>
    <message>
        <source>Tie</source>
        <extracomment>Result of rated game is a tie. Abbreviate long translations to ensure that all columns of rated games list are visible on mobile devices with small screens.</extracomment>
        <translation>Ничья</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>computer opponent for the board game Blokus</source>
        <translation>оппонент компьютерной настольной игры Блокус</translation>
    </message>
    <message>
        <source>Set maximum level to &lt;n&gt;.</source>
        <extracomment>Description for command line option --maxlevel</extracomment>
        <translation>Установить максимальный уровень на &lt;n&gt;.</translation>
    </message>
    <message>
        <source>Do not use opening books.</source>
        <extracomment>Description for command line option --nobook</extracomment>
        <translation>Не использовать открытие книг.</translation>
    </message>
    <message>
        <source>Use layout optimized for smartphones.</source>
        <extracomment>Description for command line option --mobile</extracomment>
        <translation>Используйте макет, оптимизированный для смартфонов.</translation>
    </message>
    <message>
        <source>Do not delay fast computer moves.</source>
        <extracomment>Description for command line option --nodelay</extracomment>
        <translation>Не снижать быстрые движения компьютера.</translation>
    </message>
    <message>
        <source>Set random seed to &lt;n&gt;.</source>
        <extracomment>Description for command line option --seed</extracomment>
        <translation>Установить случайный источник в &lt;n&gt;.</translation>
    </message>
    <message>
        <source>Use &lt;n&gt; threads (0=auto).</source>
        <extracomment>Description for command line option --threads</extracomment>
        <translation>Использовать &lt;n&gt; потоков (0=auto).</translation>
    </message>
    <message>
        <source>Print logging information to standard error.</source>
        <extracomment>Description for command line option --verbose</extracomment>
        <translation>Печать информации журнала до стандартной ошибки.</translation>
    </message>
    <message>
        <source>file.blksgf</source>
        <extracomment>Name of command line argument.</extracomment>
        <translation>файл.blksgf</translation>
    </message>
    <message>
        <source>Blokus SGF file to open (optional).</source>
        <translation>Blokus SGF файл для открытия (опционно).</translation>
    </message>
    <message>
        <source>--maxlevel must be between 1 and %1</source>
        <translation>--maxlevel должно быть между 1 и %1</translation>
    </message>
    <message>
        <source>--seed must be a positive number</source>
        <translation>--seed должно быть положительное число</translation>
    </message>
    <message>
        <source>--threads must be a positive number</source>
        <translation>--threads должно быть положительное число</translation>
    </message>
    <message>
        <source>Too many arguments</source>
        <translation>Слишком много аргументов</translation>
    </message>
</context>
</TS>